==> huaweicloudsdksmn-3.1.129-py2.py3-none-any.whl: huaweicloudsdksmn/v2/model/batch_subscriptions_filter_polices_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchSubscriptionsFilterPolicesRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'polices': 'list[BatchSubscriptionsFilterPolicesRequestBodyPolices]'
    }

    attribute_map = {
        'polices': 'polices'
    }

    def __init__(self, polices=None):
        """BatchSubscriptionsFilterPolicesRequestBody

        The model defined in huaweicloud sdk

        :param polices: 批量处理订阅者策略列表。
        :type polices: list[:class:`huaweicloudsdksmn.v2.BatchSubscriptionsFilterPolicesRequestBodyPolices`]
        """
        
        

        self._polices = None
        self.discriminator = None

        self.polices = polices

    @property
    def polices(self):
        """Gets the polices of this BatchSubscriptionsFilterPolicesRequestBody.

        批量处理订阅者策略列表。

        :return: The polices of this BatchSubscriptionsFilterPolicesRequestBody.
        :rtype: list[:class:`huaweicloudsdksmn.v2.BatchSubscriptionsFilterPolicesRequestBodyPolices`]
        """
        return self._polices

    @polices.setter
    def polices(self, polices):
        """Sets the polices of this BatchSubscriptionsFilterPolicesRequestBody.

        批量处理订阅者策略列表。

        :param polices: The polices of this BatchSubscriptionsFilterPolicesRequestBody.
        :type polices: list[:class:`huaweicloudsdksmn.v2.BatchSubscriptionsFilterPolicesRequestBodyPolices`]
        """
        self._polices = polices

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchSubscriptionsFilterPolicesRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdksmn-3.1.149-py2.py3-none-any.whl: huaweicloudsdksmn/v2/model/batch_subscriptions_filter_polices_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchSubscriptionsFilterPolicesRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'polices': 'list[BatchSubscriptionsFilterPolicesRequestBodyPolices]'
    }

    attribute_map = {
        'polices': 'polices'
    }

    def __init__(self, polices=None):
        r"""BatchSubscriptionsFilterPolicesRequestBody

        The model defined in huaweicloud sdk

        :param polices: 批量处理订阅者策略列表。
        :type polices: list[:class:`huaweicloudsdksmn.v2.BatchSubscriptionsFilterPolicesRequestBodyPolices`]
        """
        
        

        self._polices = None
        self.discriminator = None

        self.polices = polices

    @property
    def polices(self):
        r"""Gets the polices of this BatchSubscriptionsFilterPolicesRequestBody.

        批量处理订阅者策略列表。

        :return: The polices of this BatchSubscriptionsFilterPolicesRequestBody.
        :rtype: list[:class:`huaweicloudsdksmn.v2.BatchSubscriptionsFilterPolicesRequestBodyPolices`]
        """
        return self._polices

    @polices.setter
    def polices(self, polices):
        r"""Sets the polices of this BatchSubscriptionsFilterPolicesRequestBody.

        批量处理订阅者策略列表。

        :param polices: The polices of this BatchSubscriptionsFilterPolicesRequestBody.
        :type polices: list[:class:`huaweicloudsdksmn.v2.BatchSubscriptionsFilterPolicesRequestBodyPolices`]
        """
        self._polices = polices

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchSubscriptionsFilterPolicesRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
